import Qt 4.7

BorderImage {
    id: xaqmlDatePickerButton

    property alias operation: buttonText.text
    property alias font: buttonText.font
    property alias textColor: buttonText.color
    property bool enabled: true
    property bool framed: false
    property bool selected: false
    property bool runOp: true
    property string opcode: ""
    property bool buttonMode: true
    property int spacerBottomHeight: 1

    signal clicked

    function loadSettings() {

        if (buttonMode) {
            // display as button with markup
            if (xaqmlDatePickerButton.enabled) {
                if (xaqmlDatePickerButton.selected) shade.gradient = selectedEnabledGradient
                else shade.gradient = enabledGradient
            } else {
                if (xaqmlDatePickerButton.selected) shade.gradient = selectedDisabledGradient
                else shade.gradient = disabledGradient
            }

            // today marker
            if (xaqmlDatePickerButton.framed) todayMarker.visible = true;
            else todayMarker.visible = false;

            buttonText.color = "white"
            buttonShadow.color = "black"

            outerFrame.border.width = 1
            outerFrame.border.color = "black"

            if (xaqmlDatePickerButton.selected) innerFrame.border.width = 0
            else innerFrame.border.width = 1
            innerFrame.border.color = "#666666"

        } else {
            // display as header, no markup
            shade.color = "transparent";
            shade.border.width = 0;

            buttonText.color = "white"
            buttonShadow.color = "transparent"

            outerFrame.border.width = 0
            innerFrame.border.width = 0
        }
    }

    onFramedChanged: loadSettings()
    onEnabledChanged: loadSettings()
    onSelectedChanged: loadSettings()

    Gradient {
        id: noGradient
    }

    Gradient {
        id: enabledGradient
        GradientStop { position: 0.0; color: "#333333" }
        GradientStop { position: 0.5; color: "#3F3B3C" }
        GradientStop { position: 1.0; color: "#333333" }
    }
    Gradient {
        id: disabledGradient
        GradientStop { position: 0.0; color: "#333333" }
        GradientStop { position: 0.5; color: "#333333" }
        GradientStop { position: 1.0; color: "#333333" }
    }

    Gradient {
        id: selectedEnabledGradient
        GradientStop { position: 0.0; color: "#6396f8" }
        GradientStop { position: 0.5; color: "#2356b8" }
        GradientStop { position: 1.0; color: "#2356b8" }
    }
    Gradient {
        id: selectedDisabledGradient
        GradientStop { position: 0.0; color: "white" }
        GradientStop { position: 0.8; color: "#717171" }
        GradientStop { position: 1.0; color: "#3e3e3e" }
    }

    border { left: 10; top: 10; right: 10; bottom: 10 }

    Rectangle {
        id: shade
        anchors.fill: xaqmlDatePickerButton;  color: "black"
        gradient: enabledGradient
        smooth: true
    }

    Rectangle {
        id: outerFrame
        anchors.fill: xaqmlDatePickerButton;
        border.width: 1
        border.color: "black"
        color: "transparent"
        smooth: true
    }

    Rectangle {
        id: innerFrame
        anchors.fill: xaqmlDatePickerButton;
        anchors.leftMargin:1; anchors.rightMargin: 1; anchors.topMargin: 1; anchors.bottomMargin: 1;
        border.width: 1
        border.color: "#666666"
        color: "transparent"
        smooth: true
    }


    Text {
        id: buttonShadow
        anchors.centerIn: parent; anchors.verticalCenterOffset: +3; anchors.horizontalCenterOffset: +1
        font.family: buttonText.font.family
        font.pixelSize: buttonText.font.pixelSize
        smooth: true

        text: buttonText.text
    }

    Text {
        id: buttonText
        anchors.centerIn: parent; anchors.verticalCenterOffset: +2; anchors.horizontalCenterOffset: +1
        font.family: "Arial"
        font.pixelSize: (xaqmlDatePickerButton.width > xaqmlDatePickerButton.height ? Math.abs(xaqmlDatePickerButton.height * .6) : Math.abs(xaqmlDatePickerButton.width * .6))
        smooth:true

    }

    Rectangle {
        id: todayMarker
        anchors.left: parent.left
        anchors.leftMargin: 3
        anchors.right: parent.right
        anchors.rightMargin: 3
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 3
        height: 1

        visible: false

        color: "white"
    }

    MouseArea {
        id: mouseArea
        anchors.fill: parent
        onClicked: {
            //if (xaqmlDatePickerButton.enabled) {
            selected = true;
//            console.debug("OPERATION: " + operation);
                if (xaqmlDatePickerButton.runOp) doOp(opcode, operation);
                xaqmlDatePickerButton.clicked();
            //}
        }
    }

    states: State {
        name: "pressed"; when: mouseArea.pressed == true && xaqmlDatePickerButton.enabled
        PropertyChanges { target: shade; opacity: .4 }
    }

    Component.onCompleted: loadSettings()
}
